diff --git a/lib/mentat/system.py b/lib/mentat/system.py
index d0fd42f797676af9c447d5e9a0be5e3622be8232..90e2ae79cdaeb60241f90135017b3cbd438915e1 100644
--- a/lib/mentat/system.py
+++ b/lib/mentat/system.py
@@ -83,7 +83,7 @@ OVERALL_STATUS_MESSAGES = {
 }
 
 
-REGEXP_MENTAT_PS     = re.compile(r'\s*(\d+)\s+([^\s]+)\s+([^\s]*(?:python3?))\s+[^\s]+(mentat-[^\s]+)(?:\s+(.*))?')
+REGEXP_MENTAT_PS     = re.compile(r'\s*(\d+)\s+([^\s]+)\s+([^\s]*(?:python(?:\d+(?:\.\d+)?)?))\s+[^\s]+(mentat-[^\s]+)(?:\s+(.*))?')
 """Regular expression for selecting Mentat related processes."""
 REGEXP_MENTAT_PIDF   = re.compile(r'(.+?)(?:\.(\d+))?\.pid$')
 """Regular expression for selecting Mentat related PID files."""
diff --git a/lib/mentat/module/controller.py b/lib/mentat/module/controller.py
index 55a79d06616cb8dab6618753288976fc254f3ad0..0d6b6a808142468321564dc7b9591676934d8ae8 100644
--- a/lib/mentat/module/controller.py
+++ b/lib/mentat/module/controller.py
@@ -404,7 +404,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
         self.retc = status['resultm'][0]  # pylint: disable=locally-disabled,attribute-defined-outside-init
 
         if self.retc == mentat.system.STATUS_RT_RUNNING_OK:
-            self.logger.info("System startup seems successfull")
+            self.logger.info("System startup seems successful")
             return self.RESULT_SUCCESS
 
         self.logger.error("System startup seems to have failed")
@@ -439,7 +439,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
         self.retc = status['resultc'][0]  # pylint: disable=locally-disabled,attribute-defined-outside-init
 
         if self.retc == mentat.system.STATUS_CJ_ENABLED:
-            self.logger.info("System startup seems successfull")
+            self.logger.info("System startup seems successful")
             return self.RESULT_SUCCESS
 
         self.logger.error("System startup seems to have failed")
@@ -474,7 +474,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
                     # In case this is a first attempt the module was already not running.
                     if i == 1:
                         self.logger.info("Module '%s': Module is already not running, nothing to do", mname)
                     # Otherwise the stop was successfull.
                     else:
                         self.logger.info("Module '%s': Module successfully stopped", mname)
                     continue
@@ -506,7 +506,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
         self.retc = status['resultm'][0]  # pylint: disable=locally-disabled,attribute-defined-outside-init
 
         if self.retc == mentat.system.STATUS_RT_NOT_RUNNING:
-            self.logger.info("System shutdown seems successfull")
+            self.logger.info("System shutdown seems successful")
             return self.RESULT_SUCCESS
 
         self.logger.error("System shutdown seems to have failed")
@@ -541,7 +541,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
         self.retc = status['result'][0]  # pylint: disable=locally-disabled,attribute-defined-outside-init
 
         if self.retc == mentat.system.STATUS_CJ_ENABLED:
-            self.logger.info("System shutdown seems successfull")
+            self.logger.info("System shutdown seems successful")
             return self.RESULT_SUCCESS
 
         self.logger.error("System shutdown seems to have failed")
@@ -752,7 +752,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
             os.sync()
             os.execvp(executable, arguments)
 
             # In case the os.execv() call was successfull we should never reach
             # this point in code. If we are here, there was a critical error.
             self.logger.critical(
                 "Module '%s': Worker process '%d' was unable to execute module",
@@ -474,7 +474,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
                     if i == 1:
                         self.logger.info("Module '%s': Module is already not running, nothing to do", mname)
-                    # Otherwise the stop was successfull.
+                    # Otherwise the stop was successful.
                     else:
                         self.logger.info("Module '%s': Module successfully stopped", mname)
@@ -752,7 +752,7 @@ class MentatControllerScript(mentat.script.base.MentatBaseScript):
             os.execvp(executable, arguments)
 
-            # In case the os.execv() call was successfull we should never reach
+            # In case the os.execv() call was successful we should never reach
             # this point in code. If we are here, there was a critical error.
             self.logger.critical(